@@ -96,7 +96,7 @@ uint8_t* bytes_from_hexbytes(const char *hexbuf, size_t hexsize)
 	uint32_t i;
 
 	if( hexsize % 2 )
-		lwerror("Invalid hex string, length (%d) has to be a multiple of two!", hexsize);
+		lwerror("Invalid hex string, length (%zu) has to be a multiple of two!", hexsize);
 
 	buf = lwalloc(hexsize/2);
 
@@ -368,7 +368,7 @@ static POINTARRAY* ptarray_from_wkb_state(wkb_parse_state *s)
 
 	if( s->has_z ) ndims++;
 	if( s->has_m ) ndims++;
-	pa_size = npoints * ndims * WKB_DOUBLE_SIZE;
+	pa_size = (size_t)npoints * ndims * WKB_DOUBLE_SIZE;
 
 	/* Empty! */
 	if( npoints == 0 )
@@ -658,6 +658,13 @@ static LWCURVEPOLY* lwcurvepoly_from_wkb_state(wkb_parse_state *s)
 	if ( ngeoms == 0 )
 		return cp;
 
+	s->depth++;
+	if (s->depth >= LW_PARSER_MAX_DEPTH)
+	{
+		lwgeom_free((LWGEOM *)cp);
+		lwerror("Geometry has too many chained curves");
+		return NULL;
+	}
 	for ( i = 0; i < ngeoms; i++ )
 	{
 		geom = lwgeom_from_wkb_state(s);
@@ -665,10 +672,11 @@ static LWCURVEPOLY* lwcurvepoly_from_wkb_state(wkb_parse_state *s)
 		{
 			lwgeom_free(geom);
 			lwgeom_free((LWGEOM *)cp);
-			lwerror("Unable to add geometry (%p) to curvepoly (%p)", geom, cp);
+			lwerror("Unable to add geometry (%p) to curvepoly (%p)", (void *) geom, (void *) cp);
 			return NULL;
 		}
 	}
+	s->depth--;
 
 	return cp;
 }
@@ -715,7 +723,7 @@ static LWCOLLECTION* lwcollection_from_wkb_state(wkb_parse_state *s)
 		{
 			lwgeom_free(geom);
 			lwgeom_free((LWGEOM *)col);
-			lwerror("Unable to add geometry (%p) to collection (%p)", geom, col);
+			lwerror("Unable to add geometry (%p) to collection (%p)", (void *) geom, (void *) col);
 			return NULL;
 		}
 	}
