@@ -33,6 +33,9 @@
 #define xstr(s) str(s)
 #define str(s) #s
 
+static void
+loader_rt_error_handler(const char *fmt, va_list ap) __attribute__ ((format (printf, 1, 0)));
+
 static void
 loader_rt_error_handler(const char *fmt, va_list ap) {
 	static const char *label = "ERROR: ";
@@ -43,6 +46,9 @@ loader_rt_error_handler(const char *fmt, va_list ap) {
 	va_end(ap);
 }
 
+static void
+loader_rt_warning_handler(const char *fmt, va_list ap) __attribute__ ((format (printf, 1, 0)));
+
 static void
 loader_rt_warning_handler(const char *fmt, va_list ap) {
 	static const char *label = "WARNING: ";
@@ -53,6 +59,9 @@ loader_rt_warning_handler(const char *fmt, va_list ap) {
 	va_end(ap);
 }
 
+static void
+loader_rt_info_handler(const char *fmt, va_list ap) __attribute__ ((format (printf, 1, 0)));
+
 static void
 loader_rt_info_handler(const char *fmt, va_list ap) {
 	static const char *label = "INFO: ";
@@ -158,7 +167,7 @@ strreplace(
 	while ((tmp = strstr(tmp, oldstr)) != NULL && found != limit)
 		found++, tmp += oldlen;
 
-	length = strlen(str) + found * (newlen - oldlen);
+	length = (int)strlen(str) + found * (newlen - oldlen);
 	if ((result = (char *) rtalloc(length + 1)) == NULL) {
 		rterror(_("strreplace: Not enough memory"));
 		found = -1;
