@@ -183,7 +183,7 @@ rt_band_from_wkb(
 			memcpy(band->data.offline.path, *ptr, sz);
 			band->data.offline.path[sz] = '\0';
 
-			RASTER_DEBUGF(3, "OFFDB band path is %s (size is %d)",
+			RASTER_DEBUGF(3, "OFFDB band path is %s (size is %zu)",
 				band->data.offline.path, sz);
 
 			*ptr += sz + 1;
@@ -295,7 +295,7 @@ rt_raster_from_wkb(const uint8_t* wkb, uint32_t wkbsize) {
 	}
 	wkbend = wkb + wkbsize;
 
-	RASTER_DEBUGF(3, "Parsing header from wkb position %d (expected 0)",
+	RASTER_DEBUGF(3, "Parsing header from wkb position %zu (expected 0)",
 		d_binptr_to_pos(ptr, wkbend, wkbsize));
 
 	CHECK_BINPTR_POSITION(ptr, wkbend, wkbsize, 0);
@@ -344,7 +344,7 @@ rt_raster_from_wkb(const uint8_t* wkb, uint32_t wkbsize) {
 		rast->srid);
 	RASTER_DEBUGF(3, "rt_raster_from_wkb: Raster dims: %dx%d",
 		rast->width, rast->height);
-	RASTER_DEBUGF(3, "Parsing raster header finished at wkb position %d (expected 61)",
+	RASTER_DEBUGF(3, "Parsing raster header finished at wkb position %zu (expected 61)",
 		d_binptr_to_pos(ptr, wkbend, wkbsize));
 
 	CHECK_BINPTR_POSITION(ptr, wkbend, wkbsize, 61);
@@ -377,7 +377,7 @@ rt_raster_from_wkb(const uint8_t* wkb, uint32_t wkbsize) {
 	assert(ptr <= wkbend);
 
 	for (i = 0; i < rast->numBands; ++i) {
-		RASTER_DEBUGF(3, "Parsing band %d from wkb position %d", i,
+		RASTER_DEBUGF(3, "Parsing band %d from wkb position %zu", i,
 			d_binptr_to_pos(ptr, wkbend, wkbsize));
 
 		rt_band band = rt_band_from_wkb(rast->width, rast->height,
@@ -524,7 +524,7 @@ rt_raster_to_wkb(rt_raster raster, int outasin, uint32_t *wkbsize) {
 #if POSTGIS_DEBUG_LEVEL > 2
 	wkbend = ptr + (*wkbsize);
 #endif
-	RASTER_DEBUGF(3, "Writing raster header to wkb on position %d (expected 0)",
+	RASTER_DEBUGF(3, "Writing raster header to wkb on position %zu (expected 0)",
 		d_binptr_to_pos(ptr, wkbend, *wkbsize));
 
 	/* Write endianness */
@@ -538,7 +538,7 @@ rt_raster_to_wkb(rt_raster raster, int outasin, uint32_t *wkbsize) {
 	memcpy(ptr, &(raster->numBands), sizeof (struct rt_raster_serialized_t) - 6);
 	ptr += sizeof (struct rt_raster_serialized_t) - 6;
 
-	RASTER_DEBUGF(3, "Writing bands header to wkb position %d (expected 61)",
+	RASTER_DEBUGF(3, "Writing bands header to wkb position %zu (expected 61)",
 		d_binptr_to_pos(ptr, wkbend, *wkbsize));
 
 	/* Serialize bands now */
@@ -548,7 +548,7 @@ rt_raster_to_wkb(rt_raster raster, int outasin, uint32_t *wkbsize) {
 		int pixbytes = rt_pixtype_size(pixtype);
 
 		RASTER_DEBUGF(3, "Writing WKB for band %d", i);
-		RASTER_DEBUGF(3, "Writing band pixel type to wkb position %d",
+		RASTER_DEBUGF(3, "Writing band pixel type to wkb position %zu",
 			d_binptr_to_pos(ptr, wkbend, *wkbsize));
 
 		if (pixbytes < 1) {
@@ -575,7 +575,7 @@ rt_raster_to_wkb(rt_raster raster, int outasin, uint32_t *wkbsize) {
 		assert(!(((uint64_t) ptr) % pixbytes));
 #endif
 
-		RASTER_DEBUGF(3, "Writing band nodata to wkb position %d",
+		RASTER_DEBUGF(3, "Writing band nodata to wkb position %zu",
 			d_binptr_to_pos(ptr, wkbend, *wkbsize));
 
 		/* Add nodata value */
