@@ -1,6 +1,6 @@
 set client_min_messages to WARNING;
 
-\i ../load_topology.sql
+\i :top_builddir/topology/test/load_topology.sql
 \i :regdir/../topology/test/load_features.sql
 \i :regdir/../topology/test/more_features.sql
 \i :regdir/../topology/test/hierarchy.sql
