@@ -1,6 +1,6 @@
 set client_min_messages to WARNING;
 
-\i ../load_topology.sql
+\i :top_builddir/topology/test/load_topology.sql
 \i ../load_features.sql
 \i ../more_features.sql
 \i ../hierarchy.sql
