@@ -1,10 +1,10 @@
 set client_min_messages to WARNING;
 
-\i ../load_topology.sql
+\i :top_builddir/topology/test/load_topology.sql
 \i ../load_features.sql
 \i ../hierarchy.sql
 
--- This edges perturbate the topology so that walking around the boundaries
+-- This edges perturb the topology so that walking around the boundaries
 -- of P1 and P2 may require walking on some of them
 SELECT 'E' || TopoGeo_addLinestring('city_data', 'LINESTRING(9 14, 15 10)');
 SELECT 'E' || TopoGeo_addLinestring('city_data', 'LINESTRING(21 14, 15 18)');
@@ -36,7 +36,7 @@ SELECT 'A2-vanilla', feature_name, topology.AsTopoJSON(feature, NULL)
  ORDER BY feature_name;
 
 -- Now again with edge mapping {
-CREATE TEMP TABLE edgemap (arc_id serial, edge_id int unique);
+CREATE TEMP TABLE edgemap (arc_id bigserial, edge_id bigint unique);
 
 --- Lineal non-hierarchical
 SELECT 'L1-edgemap', feature_name, topology.AsTopoJSON(feature, 'edgemap')
